@@ -5,15 +5,15 @@
 #include <R.h>
 #include <Rdefines.h>
 
-void rExpoTree(int* RN, int* Rki, double* Rbeta, double* Rmu,
-    double* Rpsi, int* Rn, double* times, int* ttypes, 
-    double* p, double* t0, int* RSImodel, int* Rvflag, int* Rrescale);
+void rExpoTree(double* RN, int* Rki, double* Rbeta, double* Rmu,
+    double* Rpsi, int* Rn, int* parVecLen, double* times, 
+    int* ttypes, double* p, double* t0, int* RSImodel, 
+    int* Rvflag, int* Rrescale);
 
 void expoTree(int n, double* times, int* ttypes, 
     double* p, int wrklen, double* wrk, int iwrklen, int* iwrk);
 
-SEXP expoTreeEval(SEXP parameters, SEXP times, SEXP ttypes);
-SEXP expoTreeSurvival(SEXP parameters, SEXP torig);
+SEXP expoTreeEval(SEXP parameters, SEXP times, SEXP ttypes, SEXP survival);
 
 /* N = Inf reimplementation */
 /* ======================== */
